aboutsummaryrefslogtreecommitdiffstats
path: root/zellij-utils/src/plugin_api/plugin_command.rs
diff options
context:
space:
mode:
authorEdward Shin <edshin95@gmail.com>2024-07-19 10:13:16 -0400
committerGitHub <noreply@github.com>2024-07-19 16:13:16 +0200
commitb4f176facd55eeb1e5acf34f2337a68004bb802b (patch)
tree9dbb6d1d135ddaf07aefd6f9aa86fc2ab33dd4ec /zellij-utils/src/plugin_api/plugin_command.rs
parentdocs(changelog): startup delay fix (diff)
downloadsl0ppij-b4f176facd55eeb1e5acf34f2337a68004bb802b.tar.gz
sl0ppij-b4f176facd55eeb1e5acf34f2337a68004bb802b.tar.xz
sl0ppij-b4f176facd55eeb1e5acf34f2337a68004bb802b.zip
fix(terminal): only refresh process specifics for given PID in get_cwd() (#3472)
Update `get_cwd()` to only refresh process specifics for the given PID, matching the `get_cwds()` implementation. This significantly reduces the latency of opening a new Pane or Tab. On a 64-core Threadripper system, this reduces the latency of `get_cwd()` from 850ms to 1ms. On an 8-core Ryzen system, the improvement is smaller, but still perceptible.
Diffstat (limited to 'zellij-utils/src/plugin_api/plugin_command.rs')
0 files changed, 0 insertions, 0 deletions